@@ -1,5 +1,14 @@
-from .bindings import AbstractModule, ClassBinding, InstanceBinding, ItemBinding, Module, MultiBinding, PrivateModule, \
-    ProviderBinding, SelfBinding
+from .bindings import (
+    AbstractModule,
+    ClassBinding,
+    InstanceBinding,
+    ItemBinding,
+    Module,
+    MultiBinding,
+    PrivateModule,
+    ProviderBinding,
+    SelfBinding,
+)
 from .conditions import conditional_on_env_var
 from .exceptions import BindingError, InjectException, NamedError, NoBindingFound, NonInjectableTypeError
 from .injector import Injector
