@@ -1,4 +1,4 @@
-from typing import Optional, Type
+from typing import Optional, TYPE_CHECKING, Type, Union
 
 import attr
 
@@ -7,10 +7,13 @@ from opyoid.exceptions import BindingError
 from opyoid.scopes import Scope, SingletonScope
 from opyoid.utils import InjectedT, get_class_full_name
 
+if TYPE_CHECKING:
+    from typing import TypeVar
+
 
 @attr.s(auto_attribs=True, frozen=True, repr=False)
 class ClassBinding(Binding[InjectedT]):
-    _target_type: Type[InjectedT]
+    _target_type: Union[Type[InjectedT], "TypeVar"]
     bound_class: Type[InjectedT]
     scope: Type[Scope] = attr.ib(default=SingletonScope, kw_only=True)
     _named: Optional[str] = attr.ib(default=None, kw_only=True)
@@ -22,7 +25,7 @@ class ClassBinding(Binding[InjectedT]):
             raise BindingError(f"Invalid {self!r}: use a SelfBinding to bind a class to itself")
 
     @property
-    def target_type(self) -> Type[InjectedT]:
+    def target_type(self) -> Union[Type[InjectedT], "TypeVar"]:
         return self._target_type
 
     @property
