@@ -1,19 +1,22 @@
-from typing import Optional, Type
+from typing import Optional, TYPE_CHECKING, Type, Union
 
 import attr
 
 from opyoid.bindings.binding import Binding
 from opyoid.utils import InjectedT
 
+if TYPE_CHECKING:
+    from typing import TypeVar
+
 
 @attr.s(auto_attribs=True, frozen=True, repr=False)
 class InstanceBinding(Binding[InjectedT]):
-    _target_type: Type[InjectedT]
+    _target_type: Union[Type[InjectedT], "TypeVar"]
     bound_instance: InjectedT
     _named: Optional[str] = attr.ib(default=None, kw_only=True)
 
     @property
-    def target_type(self) -> Type[InjectedT]:
+    def target_type(self) -> Union[Type[InjectedT], "TypeVar"]:
         return self._target_type
 
     @property
